#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title:	      importAddTSAR.sh 
##   Description: Utility to import Traceability Server artifacts, which are 
##                added to the existing ones.
##   Usage:       importAddTSAR.sh  -file <TSAR_file> 
##                                  [-was_admin_user <was_admin_user> 
##                                   -was_admin_password <was_admin_password>] 
##                                  [-was_runas_user <was_runas_user>] 
##                                  [-dba_user <dba_user> \n\
##                                   -dba_password <dba_password>] \n\
##
#############################################################################

# Get arguments used for working with WAS
INDEX=0
for arg in $@
do
  ARGUMENTS[$INDEX]=$arg
  let "INDEX += 1"
done

while [ $INDEX -gt 0 ]
do
  let "NEXT_INDEX = $INDEX"
  let "INDEX -= 1"
  if [ ${ARGUMENTS[$INDEX]} == "-was_admin_user" ];then
    was_admin_user=${ARGUMENTS[$NEXT_INDEX]}
  elif [ ${ARGUMENTS[$INDEX]} == "-was_admin_password" ];then
    was_admin_password=${ARGUMENTS[$NEXT_INDEX]}
  elif [ ${ARGUMENTS[$INDEX]} == "-was_runas_user" ];then
    was_runas_user=${ARGUMENTS[$NEXT_INDEX]}
  fi
done

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
  . ${RFIDIC_HOME}/bin/tsEnv.sh
  . ${RFIDIC_HOME}/bin/utils.sh
  . ${RFIDIC_HOME}/bin/prereqChecks.sh
else
  . ${SCRIPT_DIR}/tsEnv.sh
  . ${SCRIPT_DIR}/utils.sh
  . ${SCRIPT_DIR}/prereqChecks.sh
fi

logFileName=TSDeployLog_`date "+%Y%m%d%H%M%S"`
assignLogFile ${scriptDir}/../logs/$logFileName
absLogPathName="`cd \"$logDir\" 2>/dev/null && pwd || echo \"$logDir\"`/$logFileName"

getWAScredentials()
{
    if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
        tsGetMessage.sh RFID05030I "$was_admin_user"
        stty -echo
        read was_admin_password
        stty echo
        echo
    fi

    if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        credentials="-user $was_admin_user -password $was_admin_password"
    else
        credentials=""
    fi
}

# Starting applications
startApplications()
{
    RFIDIC_PROPS_FILE=/tmp/cfgProps.$$
    writeProperties

    getWAScredentials
    run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${TS_HOME}/bin/jython/startApplications.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython $CPAPP_NAME $UIAPP_NAME $SIDAPP_NAME
    startTS_retCode=$?
    rm -f $RFIDIC_PROPS_FILE
}

# Stopping applications
stopApplications()
{
    RFIDIC_PROPS_FILE=/tmp/cfgProps.$$
    writeProperties

    getWAScredentials
    run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${TS_HOME}/bin/jython/stopApplications.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython $CPAPP_NAME $UIAPP_NAME $SIDAPP_NAME
    retCode=$?
    rm -f $RFIDIC_PROPS_FILE
}

# Check if WAS credentials are correct
checkWASCredentials()
{
    getWAScredentials
    serverStatus=`${WAS_HOME}/bin/serverStatus.sh $SERVERNAME $credentials`

    present=`echo "$serverStatus" | grep "ADMN0022E"`
    status=$?
}

# Check if WAS is already started
checkWASStart()
{
  if [ -z "$was_admin_user" -a -z "$was_admin_password" ];then
    isWASRunning
  else
    isWASRunning $was_admin_user $was_admin_password
  fi 
  was_status=$?
}

# Display WAS startup failure messages 
wasStartupFailureMessages()
{
  if [ "$was_status" -eq "$TRUE" ];then
    if [ $startTS_retCode -ne 0 ];then
      echo
      tsGetMessage.sh -noid RFID97080E
      echo
      tsGetMessage.sh -noid RFID97081E $absLogPathName
      echo
      exit $startTS_retCode
    fi
  fi
}

checkLogs
appendClassPathWithWASJars

#Change SSL settings in tsEnv.sh file under the sslWASSettings function
SSL_SETTINGS=`sslWASSettings`

ALL_RFIDIC_DEFINES="-DRFIDIC_HOME=${RFIDIC_HOME} $RFIDIC_MEDIUM_JAVA_HEAP $SSL_SETTINGS"

checkWASCredentials
if [ $status = 0 ];then
  echo
  tsGetMessage.sh RFID50508W
  echo
  exit 1 
fi

# Verifying 
java -classpath $CLASSPATH ${ALL_RFIDIC_DEFINES} com.ibm.ts.deployment.DeployCommand -importAdd -verify $@
RET_CODE=$?

# Display usage if arguments are incorrect
if [ $RET_CODE -eq 14 ];then
  echo
  tsGetMessage.sh -noid RFID05266I
  echo
  exit 1
fi

# Display message if import file doesn't exist
if [ $RET_CODE -eq 13 ];then
  echo
  tsGetMessage.sh -noid RFID97076E
  echo
  exit 1
fi

# Display message if system is invalid 
if [ $RET_CODE -eq 12 ];then
  echo
  tsGetMessage.sh -noid RFID97077W
  promptUserYesNo
  if [ "$?" -eq "$NO" ];then
    echo
    tsGetMessage.sh -noid RFID97072I
    echo
    exit 1
  fi
fi

# Stop WAS apps if WAS is running
checkWASStart
if [ "$was_status" -eq "$TRUE" ];then
  echo
  echo "-------- Stopping TS applications --------"
  stopApplications   >> $utilsLogFile 2>&1
else
  echo
  tsGetMessage.sh -noid RFID97082I
  echo
fi

# Import the artifacts 
echo
echo "-------- Importing TS artifacts ----------"
java -classpath $CLASSPATH ${ALL_RFIDIC_DEFINES} com.ibm.ts.deployment.DeployCommand -importAdd $@   >> $utilsLogFile 2>&1
RET_CODE=$?

# Create any required object caches based on new metadata
if [ $RET_CODE -eq 0 -o $RET_CODE -eq 1 ];then
    createObjectCaches
fi

# Start the WAS apps if WAS was originally running 
if [ "$was_status" -eq "$TRUE" ];then
  echo
  echo "-------- Starting TS applications --------"
  startApplications   >> $utilsLogFile 2>&1
fi

# Return code 0 means success 
if [ $RET_CODE -eq 0 ];then
  wasStartupFailureMessages
  echo
  tsGetMessage.sh -noid RFID97079I
  echo
else  
  # Return code 1 means success but warnings were produced with   
  if [ $RET_CODE -eq 1 ];then
    wasStartupFailureMessages
    echo
    tsGetMessage.sh -noid RFID97090W $absLogPathName
    echo
  
  # Any other return code means an error occurred  
  else
    echo
    tsGetMessage.sh -noid RFID97081E $absLogPathName
    echo
  fi
fi

exit $RET_CODE
